@@ -81,30 +81,9 @@ class DingDing_Push:
         payload = json.dumps(payload)
         res = requests.post(self.push_url, data=payload, headers=self.headers)
 
-    def app_rank_abnormal_push(self):
+    def app_args_markdown_push(self):
         """
-            * 榜单异常推送(专用)：
-        """
-        self.samePubApp_link = 'https://www.qimai.cn/app/samePubApp/appid/%s/country/cn' %(self.other_var[0])
-        self.app_rank_link = 'https://www.qimai.cn/app/rank/appid/%s/country/cn' %(self.other_var[0])
-        self.app_keyword_link = 'https://www.qimai.cn/app/keyword/appid/%s/country/cn' %(self.other_var[0])
-        # self.app_name = self.other_var[1]
-        # self.samePubApp_name = self.other_var[2]
-        # self.offline_time = self.other_var[3]
-        # self.offline_yesterday_rank = self.other_var[4]
-        payload = {
-            "msgtype": "markdown",
-            "markdown": {
-                "title": "【%s】%s" %(self.now_time[:10], self.push_title),
-                "text": "**推送事件**：%s\n\n**抓取时间**：%s\n\n**App名称**：[%s](%s)\n\n**开发商名称**：[%s](%s)\n\n**下架/清榜时间**：%s\n\n**下架/清榜前一日总榜**：%s" %(self.push_title, self.now_time, self.other_var[1], self.app_rank_link, self.other_var[2], self.samePubApp_link, self.other_var[3], self.other_var[4])
-            }
-        }
-        payload = json.dumps(payload)
-        res = requests.post(self.push_url, data=payload, headers=self.headers)
-
-    def app_args_push(self):
-        """
-            * 万能推送：
+            * 万能推送-markdown：
             推送内容自己写为Markdown形式即可；
         """
         payload = {
@@ -117,6 +96,16 @@ class DingDing_Push:
         payload = json.dumps(payload)
         res = requests.post(self.push_url, data=payload, headers=self.headers)
 
+    def app_args_text_push(self):
+        payload = {
+            "msgtype": "text",
+            "text": {
+                "content": "%s" %(self.other_var[0])
+            }
+        }
+        payload = json.dumps(payload)
+        res = requests.post(self.push_url, data=payload, headers=self.headers)
+
 # 自动登录；
 class Sing_Qimai:
     """
