@@ -118,7 +118,7 @@ class Get_ASM_Consume:
             try:
                 df = pd.read_csv('%s' % (self.yes_file_path), header=None)
             except:
-                DingDing_Push('ASM异常推送告警', '### ASM余额监控-异常告警提示\n\n**提示内容：**当前读取前1日存储账单记录异常，已再向前1日读取存储，数据或出现偏移，请注意确认！', push_url=self.push_token).app_args_push()
+                DingDing_Push('ASM异常推送告警', '### ASM余额监控-异常告警提示\n\n**提示内容：**当前读取前1日存储账单记录异常，已再向前1日读取存储，数据或出现偏移，请注意确认！', push_url=self.push_token).app_args_markdown_push()
                 df = pd.read_csv('%s' % (self.yes_yes_file_path), header=None)
 
             # 正式开始执行；
